package com.ruoyi.doubledefense.service;

import java.util.List;
import com.ruoyi.doubledefense.domain.ContractorProfession;
import com.ruoyi.doubledefense.dto.ContractorProfessionDTO;

/**
 * 承包商工种Service接口
 * 
 * @author ruoyi
 * @date 2023-08-04
 */
public interface IContractorProfessionService 
{
    /**
     * 查询承包商工种
     * 
     * @param id 承包商工种主键
     * @return 承包商工种
     */
    public ContractorProfessionDTO selectContractorProfessionById(String id);

    /**
     * 查询承包商工种列表
     * 
     * @param contractorProfession 承包商工种
     * @return 承包商工种集合
     */
    public List<ContractorProfessionDTO> selectContractorProfessionList(ContractorProfessionDTO contractorProfession);

    /**
     * 新增承包商工种
     * 
     * @param contractorProfession 承包商工种
     * @return 结果
     */
    public int insertContractorProfession(ContractorProfessionDTO contractorProfession);

    /**
     * 修改承包商工种
     * 
     * @param contractorProfession 承包商工种
     * @return 结果
     */
    public int updateContractorProfession(ContractorProfessionDTO contractorProfession);

    /**
     * 批量删除承包商工种
     * 
     * @param ids 需要删除的承包商工种主键集合
     * @return 结果
     */
    public int deleteContractorProfessionByIds(String[] ids);

}
